/*
*  Script is derivated from prefUtils.js-0.2 coded by Daniel Lindkvist
*  http://gorgias.de/mfe/
*
*  This script define functions needed to manipulate User's preferences
*
* Author: Stphane BERTIN
* http://bookmarkdd.mozdev.org
*/

//Preferences used by BookmarkDD
//bookmarkDD.remove.confirmation
//bookmarkDD.URLselect.2clicks
//bookmarkDD.Menu.addLink

var prefService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
prefService = prefService.getBranch("bookmarkDD.");

var UserPrefs = {

Load: function (aDialogId)
{
    var dialog = document.getElementById(aDialogId);
    if(!dialog) {
        alert("Preference Error: No dialog id supplied!\n");
        return false;
    }
    var prefElements = dialog.getElementsByAttribute("prefstring", "*");
    if(!prefElements) {
        return true;
    }
    for(var i=0; i<prefElements.length; i++) {
        var prefstring = prefElements[i].getAttribute("prefstring");
        var prefid = prefElements[i].getAttribute("id");
        var preftype = prefElements[i].getAttribute("preftype");
        var elt = prefElements[i].localName;
        var prefdefval = prefElements[i].getAttribute("prefdefval");

        if(!prefdefval) prefdefval = "";

        if (!preftype) {
            if (elt == "textbox")
            preftype = "string";
            else if (elt == "checkbox" || elt == "button")
            preftype = "bool";
            else if (elt == "radiogroup" || elt == "menulist")
            preftype = "int";
        }
        var prefvalue = UserPrefs.getPref(preftype, prefstring, prefdefval);
        if(prefvalue == "!/!ERROR_UNDEFINED_PREF!/!") { prefvalue = prefdefval; }
        switch(elt) {
            case "textbox":
                prefElements[i].value = prefvalue;
                break;
            case "checkbox":
                prefElements[i].checked = prefvalue;
                break;
            case "button":
                prefElements[i].checked = prefvalue;
                break;
            case "radiogroup":
                prefElements[i].value = prefvalue;
                break;
            case "menulist":
                prefElements[i].selectedIndex = prefvalue;
                break;
        }
    }

    return true;
},      // End PrefsLoad


Save: function (aDialogId)
{
    var dialog = document.getElementById(aDialogId);
    if(!dialog) {
        alert("Preference Error: No dialog id supplied!\n");
        return false;
    }
    var prefElements = dialog.getElementsByAttribute("prefstring", "*");

    for(var i=0; i<prefElements.length; i++) {
        var prefstring = prefElements[i].getAttribute("prefstring");
        var preftype = prefElements[i].getAttribute("preftype");

        var elt = prefElements[i].localName;
        if (!preftype) {
            if (elt == "textbox") preftype = "string";
            else if (elt == "checkbox" || elt == "button") preftype = "bool";
            else if (elt == "radiogroup" || elt == "menulist") preftype = "int";
        }
        var prefvalue; 
        if (elt == "checkbox") prefvalue = prefElements[i].checked;
        else if (elt == "button") prefvalue = prefElements[i].checked;
        else if (elt == "radiogroup" || elt == "menulist") prefvalue = prefElements[i].selectedIndex;
        else if (elt == "textbox") prefvalue = prefElements[i].value;

        UserPrefs.setPref(preftype, prefstring, prefvalue);
    }
    return true;
},      // End Save


getPref: function (aPrefType, aPrefString, aDefaultFlag)
{
    try {
        switch(aPrefType) {
            case "bool":
                return prefService.getBoolPref(aPrefString);
            case "int":
                return prefService.getIntPref(aPrefString);
            case "localizedstring":
                return prefService.getLocalizedUnicharPref(aPrefString); // not working?
            case "color":
            case "string":
            default:
                return prefService.getCharPref(aPrefString); 
        }
    }catch(e) {
        alert("Preference Error: "+ e + "\n");
    }
    return "!/!ERROR_UNDEFINED_PREF!/!";
}, //End of getPref


setPref: function (aPrefType, aPrefString, aValue)
{
    try {
        switch (aPrefType) {
            case "bool":
                prefService.setBoolPref(aPrefString, aValue);
                break;
            case "int":
                prefService.setIntPref(aPrefString, aValue);
                break;
            case "color":
            case "string":
            case "localizedstring":
            default:
                prefService.setCharPref(aPrefString, aValue);
                break;
        }
    } catch(e) {
        alert("Preference Error: "+ e + "\n");
    }
    return true;
} //End of setPref

} //End of UserPrefs
